@@ -12,3 +12,11 @@
 #undef HAVE_PNG
 #undef HAVE_JPEG
 #undef HAVE_PROGRESSIVE_JPEG
+#undef ENABLE_BONOBO_FILESEL
+#undef ENABLE_EVOLUTION
+#undef ENABLE_GNOCAM
+#undef GETTEXT_PACKAGE
+#undef GCONFTOOL
+#undef GCONF_CONFIG_SOURCE
+#undef INSTALL_GCONF_CONFIG_SOURCE
+
