@@ -15,9 +15,15 @@
 #include <gtk/gtkmarshal.h>
 #include <gtk/gtktypeutils.h>
 #include <gtk/gtknotebook.h>
-
+#include <libgnome/gnome-macros.h>
 #include <eog-preferences.h>
 
+
+GNOME_CLASS_BOILERPLATE (EogPreferences,
+			 eog_preferences,
+			 GtkDialog,
+			 GTK_TYPE_DIALOG);
+
 struct _EogPreferencesPrivate {
 	EogWindow          *window;
 	
@@ -25,8 +31,6 @@ struct _EogPreferencesPrivate {
 	
 };
 
-static GtkDialogClass *eog_preferences_parent_class;
-
 static void
 eog_preferences_destroy (GtkObject *object)
 {
@@ -41,10 +45,10 @@ eog_preferences_destroy (GtkObject *object)
 	preferences = EOG_PREFERENCES (object);
 
 	if (preferences->priv->window)
-		gtk_object_unref (GTK_OBJECT (preferences->priv->window));
+		g_object_unref (preferences->priv->window);
 	preferences->priv->window = NULL;
 
-	GTK_OBJECT_CLASS (eog_preferences_parent_class)->destroy (object);
+	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -52,57 +56,29 @@ eog_preferences_finalize (GObject *object)
 {
 	EogPreferences *preferences;
 
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (EOG_IS_PREFERENCES (object));
-
 	preferences = EOG_PREFERENCES (object);
 
 	g_free (preferences->priv);
 
-	G_OBJECT_CLASS (eog_preferences_parent_class)->finalize (object);
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void
-eog_preferences_class_init (EogPreferences *klass)
+eog_preferences_class_init (EogPreferencesClass *klass)
 {
 	GtkObjectClass *object_class = (GtkObjectClass *)klass;
 	GObjectClass *gobject_class = (GObjectClass *)klass;
 
-	eog_preferences_parent_class = gtk_type_class (GTK_TYPE_DIALOG);
-
 	object_class->destroy = eog_preferences_destroy;
 	gobject_class->finalize = eog_preferences_finalize;
 }
 
 static void
-eog_preferences_init (EogPreferences *preferences)
+eog_preferences_instance_init (EogPreferences *preferences)
 {
 	preferences->priv = g_new0 (EogPreferencesPrivate, 1);
 }
 
-GtkType
-eog_preferences_get_type (void)
-{
-	static GtkType type = 0;
-
-	if (!type) {
-		GtkTypeInfo info = {
-			"EogPreferences",
-			sizeof (EogPreferences),
-			sizeof (EogPreferencesClass),
-			(GtkClassInitFunc)  eog_preferences_class_init,
-			(GtkObjectInitFunc) eog_preferences_init,
-			NULL, /* reserved 1 */
-			NULL, /* reserved 2 */
-			(GtkClassInitFunc) NULL
-		};
-
-		type = gtk_type_unique (GTK_TYPE_DIALOG, &info);
-	}
-
-	return type;
-}
-
 static void
 add_property_control_page (EogPreferences *preferences,
 			   Bonobo_PropertyControl property_control,
@@ -160,7 +136,7 @@ eog_preferences_construct (EogPreferences *preferences,
 	g_return_val_if_fail (EOG_IS_WINDOW (window), NULL);
 
 	preferences->priv->window = window;
-	gtk_object_ref (GTK_OBJECT (window));
+	g_object_ref (window);
 
 	gtk_window_set_title (GTK_WINDOW (preferences), _("Eye of Gnome Preferences"));
 	gtk_dialog_add_button (GTK_DIALOG (preferences), GTK_STOCK_CLOSE,
@@ -170,9 +146,9 @@ eog_preferences_construct (EogPreferences *preferences,
 	gtk_widget_show (preferences->priv->notebook);
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (preferences)->vbox), 
 			   preferences->priv->notebook);
-	gtk_signal_connect (GTK_OBJECT (preferences), "response", 
-			    GTK_SIGNAL_FUNC (gtk_widget_destroy), 
-			    preferences);
+	g_signal_connect (preferences, "response", 
+			  G_CALLBACK (gtk_widget_destroy), 
+			  preferences);
 
 	CORBA_exception_init (&ev);
 
@@ -195,6 +171,11 @@ eog_preferences_construct (EogPreferences *preferences,
 
 	page_count = Bonobo_PropertyControl__get_pageCount (prop_control, &ev);
 
+	if (page_count == 1) {
+		gtk_notebook_set_show_border (GTK_NOTEBOOK (preferences->priv->notebook), FALSE);
+		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (preferences->priv->notebook), FALSE);
+	}
+	
 	for (i = 0; i < page_count; i++)
 	    add_property_control_page (preferences, prop_control,
 				       uic, i, &ev);
@@ -205,15 +186,26 @@ eog_preferences_construct (EogPreferences *preferences,
 	return preferences;
 }
 
+static void
+destroy_prefs_window (EogWindow *window,
+		      EogPreferences *preferences)
+{
+	gtk_widget_destroy (GTK_WIDGET (preferences));
+}
+
 GtkWidget *
 eog_preferences_new (EogWindow *window)
 {
 	EogPreferences *preferences;
 	
-	g_return_val_if_fail (window != NULL, NULL);
 	g_return_val_if_fail (EOG_IS_WINDOW (window), NULL);
 
-	preferences = gtk_type_new (eog_preferences_get_type ());
+	preferences = g_object_new (eog_preferences_get_type (), NULL);
 
+	/* Kind of hack, but can't seem to find a way to change
+	   a GtkDialog's flags after its been created */
+	g_signal_connect (G_OBJECT (window), "destroy",
+			  G_CALLBACK (destroy_prefs_window), preferences);
+	
 	return GTK_WIDGET (eog_preferences_construct (preferences, window));
 }
