@@ -254,6 +254,14 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname
 	raise_and_focus (about);
 }
 
+static void
+verb_HelpContent_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
+{
+	GError *error = NULL;
+	gnome_help_display ("eog",NULL,&error);
+}
+
+
 static void
 verb_DnDNewWindow_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
@@ -591,10 +599,7 @@ eog_window_new (void)
 	EogWindow *window;
 	BonoboUIContainer *uic;
 
-	window = EOG_WINDOW (g_object_new (EOG_TYPE_WINDOW, NULL));
-
-	uic = bonobo_ui_container_new ();
-	bonobo_window_construct (BONOBO_WINDOW (window), uic, "eog", _("Eye of Gnome"));
+	window = EOG_WINDOW (g_object_new (EOG_TYPE_WINDOW, "win_name", "eog", "title", _("Eye of Gnome"), NULL));
 
 	eog_window_construct (window);
 
@@ -624,6 +629,7 @@ static BonoboUIVerb eog_app_verbs[] = {
 	BONOBO_UI_VERB ("FileExit",      verb_FileExit_cb),
 	BONOBO_UI_VERB ("Preferences",   verb_Preferences_cb),
 	BONOBO_UI_VERB ("HelpAbout",     verb_HelpAbout_cb),
+	BONOBO_UI_VERB ("Help",          verb_HelpContent_cb),
 	BONOBO_UI_VERB ("DnDNewWindow",  verb_DnDNewWindow_cb),
 	BONOBO_UI_VERB ("DnDSameWindow", verb_DnDSameWindow_cb),
 	BONOBO_UI_VERB ("DnDCancel",     verb_DnDCancel_cb),
